@@ -90,6 +90,15 @@ export const registerBbyButtons = () => {
       'add-quiz-step',
       'ipybbycell'
     ),
+    Jupyter.keyboard_manager.actions.register(
+      {
+        help: '添加「Upload File Step」',
+        icon: 'fa-upload',
+        handler: addUploadFileStep,
+      },
+      'add-quiz-step',
+      'ipybbycell'
+    ),
     Jupyter.keyboard_manager.actions.register(
       {
         help: '添加「折叠块」',
@@ -404,6 +413,34 @@ Player(vid='--替换你的视频id，上传地址 https://www.boyuai.com/elites/
   insertCodeCellBelow(quizString);
 };
 
+const addUploadFileStep = function () {
+  insertMarkdownCellBelow('### 步骤标题');
+
+  insertCodeCellBelow(`#platform-desc
+from ipyaliplayer import Player
+Player(vid='--替换你的视频id，上传地址 https://www.boyuai.com/elites/admin/public-video', aspect_ratio=4/3)
+`);
+
+  insertMarkdownCellBelow(`<!--步骤描述 -->
+
+#### 知识点
+- 总结视频中的知识点`);
+
+  insertCodeCellBelow(`#platform-upload-file
+[
+  {
+      "file-type": "image",
+      "file-max-count": 1,
+      "title": "请上传一张图片"
+  },
+  {
+      "file-type": "doc",
+      "file-max-count": 2,
+      "title": "请上传全部的文本文件"
+  }
+]`);
+};
+
 const addDetailStep = function () {
   insertCodeInCurrentMarkdownCell(`
 <details>
@@ -690,7 +727,7 @@ const syncLesson = async function () {
     }
     // 同步
     _sync();
-  } catch (error) {
+  } catch (error: any) {
     Jupyter.dialog.modal({
       title: '可能存在错误，请确认是否同步',
       body:
